@@ -1,6 +1,9 @@
 from eloquentarduino.ml.data.preprocessing.pipeline.Pipeline import Pipeline
 from eloquentarduino.ml.data.preprocessing.pipeline.Diff import Diff
+from eloquentarduino.ml.data.preprocessing.pipeline.FFT import FFT
 from eloquentarduino.ml.data.preprocessing.pipeline.MinMaxScaler import MinMaxScaler
 from eloquentarduino.ml.data.preprocessing.pipeline.Norm import Norm
+from eloquentarduino.ml.data.preprocessing.pipeline.PolynomialFeatures import PolynomialFeatures
 from eloquentarduino.ml.data.preprocessing.pipeline.SelectKBest import SelectKBest
 from eloquentarduino.ml.data.preprocessing.pipeline.StandardScaler import StandardScaler
+from eloquentarduino.ml.data.preprocessing.pipeline.Window import Window
